#
# spec file for package hivex
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Michal Hrusecky <mhrusecky@novell.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without perl_bingings
%bcond_without python_bindings
%bcond_without ocaml_bindings
Name:           hivex
VCS: https://src.suse.de/SLFO-pool/hivex#a20df8e0993294feb9c4f4e1ebd5f06ddc4e2bfb0f7ccda5f1aab7c73e2cb3e1
Version:        1.3.24
Release:        160000.1.17
Summary:        Windows "Registry Hive" extraction library
License:        GPL-2.0-only AND LGPL-2.1-only
URL:            http://libguestfs.org/hivex.3.html
Source:         http://libguestfs.org/download/hivex/%{name}-%{version}.tar.gz
Source2:        http://libguestfs.org/download/hivex/%{name}-%{version}.tar.gz.sig
Source3:        %{name}.keyring
Source4:        %{name}.rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
Requires:       perl(Getopt::Long)
Requires:       perl(Pod::Usage)
Requires:       perl(Win::Hivex)
Requires:       perl(Win::Hivex::Regedit)

%description
Hivex is a library for extracting the contents of Windows "Registry
Hive" files. It is designed to be secure against buggy or malicious
registry files.

%package devel
Summary:        Development files for hivex
Requires:       libhivex0 = %{version}

%description devel
Development files for hivex. Hivex is a Windows Registry Hive extraction
library.

%package -n libhivex0
Summary:        Windows Registry Hive extraction library

%description -n libhivex0
Hivex is a Windows Registry Hive extraction library.

%if %{with perl_bingings}
%package -n perl-Win-Hivex
Summary:        Perl bindings for hivex
BuildRequires:  perl(ExtUtils::MakeMaker)
BuildRequires:  perl(IO::Stringy)
BuildRequires:  perl(Test::More)
Requires:       perl = %{perl_version}
%{perl_requires}

%description -n perl-Win-Hivex
This subpackage contains the Perl bindings for hivex.
Hivex is a Windows Registry Hive extraction library.

%endif

%if %{with python_bindings}
%package -n python3-hivex
Summary:        Python bindings for libhivex
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
Provides:       python-hivex = %{version}-%{release}
Obsoletes:      python-hivex < %{version}-%{release}

%description -n python3-hivex
This subpackage contains the Python bindings for hivex.
Hivex is a Windows Registry Hive extraction library.
%endif

%if %{with ocaml_bindings}
%package -n ocaml-hivex
Summary:        OCAML bindings for libhivex
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-rpm-macros
%{?ocaml_preserve_bytecode}

%description -n ocaml-hivex
This subpackage contains the OCAML bindings for hivex.
Hivex is a Windows Registry Hive extraction library.

%package -n ocaml-hivex-devel
Summary:        OCAML bindings development files for libhivex
Requires:       %{name}-devel = %{version}
Requires:       ocaml-hivex = %{version}

%description -n ocaml-hivex-devel
This subpackage contains the OCAML bindings development file
for hivex. Hivex is a Windows Registry Hive extraction library.
%endif

%lang_package

%prep
%autosetup -p1

%build
sed -i 's:%{_bindir}/env perl:%{_bindir}/perl:' regedit/hivexregedit

if command -v python3-config >/dev/null
then
	export PYTHON="python3"
	export PYTHON_LIBS=$(python3-config --libs)
	export PYTHON_CFLAGS=$(python3-config --cflags)
	export PYTHON_EXT_SUFFIX=.so
fi
%configure --disable-static
# 'INSTALLDIRS' ensures that perl libs are installed in the vendor dir instead of the site dir
%make_build \
	LD_RUN_PATH= \
	INSTALLDIRS=vendor

%install
%make_install INSTALLDIRS=vendor

%if %{with perl_bingings}
%perl_process_packlist
%perl_gen_filelist
# the macro above packages everything, here only the perl files are desrired
grep "%{perl_vendorarch}/" %{name}.files | tee t
mv t %{name}.files
%endif
#
rm -f %{buildroot}/%{_libdir}/*.{l,}a
touch %{name}.lang
%find_lang %{name}

%post -n libhivex0 -p /sbin/ldconfig
%postun -n libhivex0 -p /sbin/ldconfig

%files
%{_bindir}/*
%{_mandir}/*/*

%files devel
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_libdir}/*.so

%files -n libhivex0
%license LICENSE
%{_libdir}/*.so.*

%if %{with python_bindings}
%files -n python3-hivex
%{python3_sitearch}/*
%endif

%if %{with perl_bingings}
%post -n perl-Win-Hivex -p /sbin/ldconfig
%postun -n perl-Win-Hivex -p /sbin/ldconfig

%files -n perl-Win-Hivex -f %{name}.files
%endif
#

%if %{with ocaml_bindings}
%files -n ocaml-hivex

%files -n ocaml-hivex-devel
%{_libdir}/ocaml/hivex
%{_libdir}/ocaml/stublibs
%endif

%files lang -f %{name}.lang

%changelog
* Wed Sep  4 2024 olaf@aepfle.de
- Update hivex to version 1.3.24
  * no changelog provided
* Wed Jan 25 2023 carnold@suse.com
- Update hivex to version 1.3.23
  * jsc#PED-2113
  * Updated langauge files
  * Various build fixes
  * Improved windows support
* Tue Dec 14 2021 ohering@suse.de
- Add python-rpm-macros (bsc#1180125)
* Sun Sep 26 2021 ohering@suse.de
- move all ocaml libraries to devel package to align with our
  OCaml packaging
* Fri Aug  6 2021 carnold@suse.com
- bsc#1189060 - VUL-0: CVE-2021-3622: hivex: hivex: stack overflow
  due to recursive call of _get_children. Update to version 1.3.21
  hivex-1.3.21.tar.gz
  hivex-1.3.21.tar.gz.sig
* Tue May  4 2021 carnold@suse.com
- Update to version 1.3.20
  * Fixes bsc#1185013 - VUL-0: CVE-2021-3504: hivex: missing bounds
    check within hivex_open()
  * Increase HIVEX_MAX_VALUES
  * Updated translations
* Wed Apr 21 2021 ohering@suse.de
- Remove ocaml_native_compiler conditional
  build native target unconditionally
* Mon Jan 11 2021 jgwang@suse.com
- Update to version 1.3.19
  * ocaml: Throw exception if malloc returns NULL
  * ocaml: Cast return from String_val to (char *)
  * ocaml: Use caml_alloc_initialized_string
  * Remove extra @LIBS@ from pkg-config file
  * Win::Hivex::Regedit: Ignore comments
  * Win::Hivex::Regedit: Accept CRLF line endings
* Wed Feb  5 2020 steven.kowalik@suse.com
- Switch to building using Python 3, as a consequence rename python
  binding package to python3-hivex.
- Drop unneeded Recommends and Group lines.
- Make use of python3_sitearch macro to drop pyver variable.
- Use python3-config to determine CFLAGS and libraries.
- Run spec-cleaner against the specfile.
* Fri Nov  1 2019 ohering@suse.de
- Fix bytecode build
- Remove defattr and BuildRoot
- disablement of lto comes via ocaml macros
* Thu Aug  8 2019 ohering@suse.de
- disable lto
- Update to version 1.3.18
  * ocaml: Link the C bindings with LDFLAGS (RHBZ#1548536)
  * perl: fix format of croak for RLenValue
  * Update gnulib to latest.
  * lib: Reset errno to zero to avoid erroneously returning E2BIG
* Mon Mar  5 2018 cbosdonnat@suse.com
- Update to version 1.3.15
  * Improved performance by using a cache of iconv handles, especially
    when dumping out large hives.
  * Add the ‘hivexregedit --max-depth’ option for exports, so you can
    dump out only the top N-level keys.
  * ‘hivexsh -u’ flag allows you to open some broken hives.
  * Fixes to broken POD documentation in some places.
  * Fixes for OCaml 4.06 safe strings.
* Thu Sep 28 2017 olaf@aepfle.de
- Rename Group Ocaml to OCaml
* Thu Sep 21 2017 jengelh@inai.de
- Rectify RPM groups.
* Tue Sep 19 2017 cbosdonnat@suse.com
- Add ocaml-hivex and hivex-devel as dependencies for ocaml-hivex-devel
* Mon Jul 31 2017 cbosdonnat@suse.com
- Update to version 3.14
- Build OCAML binding
* Tue Oct 27 2015 olaf@aepfle.de
- Update to version 3.12
* Mon Mar 16 2015 jengelh@inai.de
- Retrieve and verify GPG signature. Resolve some orthographic and
  typographic errors in descriptions. Make descriptions more
  similar.
- Run spec-beautifier
* Sun Jan 18 2015 p.drouand@gmail.com
- Update to version 3.11
  * extra-tests: Add trivial fuzz tester
  * handle: Check that pages do not extend beyond the end of the file.
- Use download Url as source
- Split out translation files into lang subpackage
- Recommend hivex-lang
* Tue May 13 2014 ohering@suse.de
- update to version 1.3.10
  many bugfixes, see included changelog for details
* Mon Aug  5 2013 cfarrell@suse.com
- license update: LGPL-2.1 and GPL-2.0
  README states license is LGPL-2.1 (only) and LICENSE confirms. There is a
  significant number of GPL-2.0 files in test and examples
* Wed Jul 31 2013 ohering@suse.de
- update to version 1.3.8
* Sun Feb 24 2013 ohering@suse.de
- BuildRequire: perl-macros only in sles11 builds to fix build in 11.4
* Wed Nov  7 2012 ohering@suse.de
- update to version 1.3.7
* Sat Sep  1 2012 ohering@suse.de
- move python bindings to python-hivex
* Sat Sep  1 2012 ohering@suse.de
- enable perl bindings, package them in perl-Win-Hivex
* Tue Jul  3 2012 ohering@suse.de
- update to version 1.3.6
* Mon Jul  2 2012 ohering@suse.de
- workaround buggy python detection by adding python to BuildRequires
- fix filelist to build on sles11
* Tue Sep 27 2011 mhrusecky@suse.cz
- initial hivex package (version 1.3.1)
